#!/usr/bin/env python3
# -*- coding: utf-8 -*-

UNAPI = {
  "k10plus": "http://unapi.k10plus.de",
  "gbv": "http://unapi.gbv.de"
}

HYDRA = {
  "zdb": "https://www.zeitschriftendatenbank.de/api/hydra",
  "isil": "https://sigel.staatsbibliothek-berlin.de/api/hydra"
}

LD = {
  "dnb": "http://d-nb.info",
  "zdb": "http://ld.zdb-services.de/data/",
  "isil": "http://ld.zdb-services.de/resource/organisations/"
}

SRU = {
  "dnb": "https://services.dnb.de/sru/dnb",
  "b3kat": "http://bvbr.bib-bvb.de:5661/bvb01sru",
  "kobv": "http://z3950.kobv.de/k2",
  "hebis": "http://cbsopac.rz.uni-frankfurt.de/sru/DB=2.1/",
  "hebis-gbv": "http://sru.gbv.de/hebis",
  "swb": "https://sru.bsz-bw.de/swb",
  "swb-gbv": "http://sru.gbv.de/swb",
  "gvk": "http://sru.k10plus.de/gvk",
  "k10plus": "http://sru.k10plus.de/opac-de-627",
  "stabikat": "http://sru.gbv.de/stabikat",
  "zdb": "http://services.dnb.de/sru/zdb",
  "gnd": "https://services.dnb.de/sru/authorities",
  "ognd": "https://sru.bsz-bw.de/ognd",
  "ognd-gbv": "http://sru.gbv.de/ognd",
  "isil": "http://services.dnb.de/sru/bib",
  "hpb": "http://sru.gbv.de/hpb",
  "cerl-thesaurus": "https://data.cerl.org/thesaurus/_sru",
  "kalliope": "http://kalliope-verbund.info/sru",
  "vd17": "http://sru.k10plus.de/vd17",
  "vd18": "http://sru.gbv.de/vd18",
  "gjz18": "http://sru.gbv.de/gjz18",
  "idz": "http://sru.gbv.de/idz",
}
